@@ -31,6 +31,7 @@
 
 #include <KAboutData>
 #include <KConfigGroup>
+#include <KCrash>
 #include <KSharedConfig>
 #include <KLocalizedString>
 #include <KDBusService>
@@ -39,6 +40,9 @@ int main( int argc, char **argv )
 {
     Dragon::PlayerApplication app(argc, argv);
     app.setOrganizationDomain("org.kde");
+#ifdef WITH_KCRASH_INIT
+    KCrash::initialize();
+#endif
 
     KLocalizedString::setApplicationDomain("dragonplayer");
 
